/*********************************************************************
 *
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2008, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the Willow Garage nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.

 *
 * \author Sachin Chitta, Ioan Sucan
 *********************************************************************/

#include "planning_environment/monitors/environment_server_setup.h"

bool planning_environment::EnvironmentServerSetup::configure(void)
{
  std::string global_frame_id;
  node_handle_.param<std::string>("group", group_, std::string());
  node_handle_.param<bool>("use_collision_map", use_collision_map_, true);
  node_handle_.param<std::string>("global_frame", global_frame_id, "");
  if (group_.empty())
  {
    ROS_ERROR("No 'group' parameter specified. Without the name of the group of joints to monitor, environment server cannot start");
    return false;
  }

  //figuring out whether robot_description has been remapped

  ros::NodeHandle global_nh;

  std::string robot_description_name = global_nh.resolveName("robot_description", true);

  // monitor robot
  collision_models_ = new planning_environment::CollisionModels(robot_description_name);
  if(global_frame_id.empty())
    planning_monitor_ = new planning_environment::PlanningMonitor(collision_models_, &tf_);
  else
    planning_monitor_ = new planning_environment::PlanningMonitor(collision_models_, &tf_, global_frame_id);

  planning_monitor_->use_collision_map_ = use_collision_map_;
  if (!collision_models_->loadedModels())
    return false;

  if (!collision_models_->getKinematicModel()->hasGroup(group_))
  {
    ROS_ERROR("Group '%s' is not known", group_.c_str());
    collision_models_->getKinematicModel()->printModelInfo(std::cout);
    return false;
  }
  else
    ROS_INFO("Configuring server for '%s'", group_.c_str());

  if (planning_monitor_->getExpectedJointStateUpdateInterval() > 1e-3)
    planning_monitor_->waitForState();
  if (planning_monitor_->getExpectedMapUpdateInterval() > 1e-3 && use_collision_map_)
    planning_monitor_->waitForMap();

  return true;
}

